==> core-1.0.8-RC1-sources.jar: commonMain/io/data2viz/charts/config/EventConfig.kt <==
package io.data2viz.charts.config

import io.data2viz.charts.chart.Chart
import io.data2viz.charts.chart.mark.Mark
import io.data2viz.charts.core.*
import io.data2viz.viz.HasMetaKeys
import io.data2viz.viz.KMouseEvent


/**
 * [Chart] events configuration.
 *
 * - zoom
 * - pan
 * - highlight
 * - selection
 */
public interface EventConfig {

    /**
     * Define the behavior for highlighting a [Mark].
     */
    public var highlightMode: HighlightMode

    /**
     * Define how the [Mark] sign will "trigger" (rollover, nearest, ...)
     */
    public var triggerMode: TriggerMode

    /**
     * Define the behavior for selecting a [Mark].
     */
    public var selectionMode: SelectionMode

    /**
     * Define the behavior for reacting to a select Datum.
     */
    public var selectionPattern: SelectionPattern

    /**
     * Define the behavior for reacting to a highlight Datum.
     */
    public var highlightPattern: SelectionPattern

    //todo should be in zoom config?
    /**
     * Define the zoom behavior.
     */
    public var zoomMode: ZoomMode

    /**
     * Allow for zooming with the mouse wheel (when available) given a [HasMetaKeys] event.
     *
     * Examples:
     * - To disable mouse wheel zoom completely just set the variable to { false }.
     * - To enable mouse wheel zoom without meta-key shortcut just set the variable to { true }.
     * - To enable mouse wheel zoom for both ALT or SHIFT keys set this to { altKey || shiftKey }.
     *
     * Defaults to { ctrlKey }.
     */
    public var zoomEnableOnMouseWheel: HasMetaKeys.() -> Boolean

    /**
     * Define the panning behavior.
     */
    public var panMode: PanMode


    /**
     * Defines the [UserAction] started on a mouse down.
     *
     * Default implementation is :
     *
     * ```
     * { event ->
     *    when {
     *        event.ctrlKey || event.metaKey   -> UserAction.Zoom
     *        event.altKey                     -> UserAction.Pan
     *        else                             -> UserAction.Select
     *    }
     * }
     * ```
     */
    public var getUserActionOnMouseDown: (KMouseEvent) -> UserAction?

//    /**
//     * Defines the [UserAction] started on a mouse wheel.
//     *
//     * Default implementation is :
//     *
//     * ```
//     * { event ->
//     *    when {
//     *        event.ctrlKey || event.metaKey   -> UserAction.Zoom
//     *        event.altKey                     -> UserAction.Pan
//     *        else                             -> UserAction.Select
//     *    }
//     * }
//     * ```
//     */
//    public var getUserActionOnMouseWheel: (KMouseEvent) -> UserAction?
}

==> core-1.0.12-RC1-sources.jar: commonMain/io/data2viz/charts/config/EventConfig.kt <==
package io.data2viz.charts.config

import io.data2viz.charts.chart.Chart
import io.data2viz.charts.chart.mark.Mark
import io.data2viz.charts.core.*
import io.data2viz.viz.HasMetaKeys
import io.data2viz.viz.KPointerEvent


/**
 * [Chart] events configuration.
 *
 * - zoom
 * - pan
 * - highlight
 * - selection
 */
public interface EventConfig {

    /**
     * Define the behavior for highlighting a [Mark].
     */
    public var highlightMode: HighlightMode

    /**
     * Define how the [Mark] sign will "trigger" (rollover, nearest, ...)
     */
    public var triggerMode: TriggerMode

    /**
     * Define the behavior for selecting a [Mark].
     */
    public var selectionMode: SelectionMode

    /**
     * Define the behavior for reacting to a select Datum.
     */
    public var selectionPattern: SelectionPattern

    /**
     * Define the behavior for reacting to a highlight Datum.
     */
    public var highlightPattern: SelectionPattern

    //todo should be in zoom config?
    /**
     * Define the zoom behavior.
     */
    public var zoomMode: ZoomMode

    /**
     * Allow for zooming with the mouse wheel (when available) given a [HasMetaKeys] event.
     *
     * Examples:
     * - To disable mouse wheel zoom completely just set the variable to { false }.
     * - To enable mouse wheel zoom without meta-key shortcut just set the variable to { true }.
     * - To enable mouse wheel zoom for both ALT or SHIFT keys set this to { altKey || shiftKey }.
     *
     * Defaults to { ctrlKey }.
     */
    @Deprecated("Use chart.getChartActionOnUserEvent with context.event.type == EventType.Wheel")
    public var zoomEnableOnMouseWheel: HasMetaKeys.() -> Boolean

    /**
     * Define the panning behavior.
     */
    public var panMode: PanMode

    @Deprecated("Use chart.getChartActionOnUserEvent", ReplaceWith("getChartActionOnUserEvent", "io.data2viz.charts.config.getChartActionOnUserEvent"))
    public var getUserActionOnMouseDown: (KPointerEvent) -> UserAction?
}
